==> telemetrix-rpi-pico-0.2.tar.gz: telemetrix-rpi-pico-0.2/README.md <==
# Telemetrix-RPi-Pico

This is an early version of a Telemetrix client for the Raspberry Pi Pico.

This is a work in progress.

A full User's Guide is under development.

A Python API for may be found [here.](https://htmlpreview.github.com/?https://github.com/MrYsLab/telemetrix-rpi-pico/blob/master/html/telemetrix_rpi_pico/index.html) 

The Pico server code may be viewed [here.](https://github.com/MrYsLab/Telemetrix4RpiPico)

The following functionality is implemented in this release:

* Autodetect and connection to a single PICO connected to the PC.
* Automatic board reset of the PICO using the watchdog timer when application exits.
    * Board will blink twice upon reset.
* Retrieval of the PICO unique ID.
* Analog Input
* Digital Input, Digital Input Pullup, Digital Input Pulldown
* PWM output
* Loopback (for client/server link debugging)


## To install The Client Library:

**Linux/macOS:**

sudo pip3 install telemetrix-rpi-pico

**Windows:**

pip install telemetrix-rpi-pico

## To Install The Pico Server Application
1. [Download](https://github.com/MrYsLab/Telemetrix4RpiPico/raw/master/cmake-build-release/Telemetrix4RpiPico.uf2) 
   and save the .uf2 file.
2. Place the Pico in file upload mode:
   
   A. Press and hold the BOOTSEL button while applying power. 
   B. Release the BOOTSEL button.
   C. In you file explorer, you should a new folder appear called: RPI-RP2.
   D. Drag the .uf2 file into this folder to upload the code.
   
3. [Download,](https://github.com/MrYsLab/telemetrix-rpi-pico/archive/master.zip) 
   save, and uncompress the teletmetrix-rpi-pico Github repository.
   
4. Open the _examples_ directory and run any of the examples. You may
modify them to suit your needs.

==> telemetrix-rpi-pico-0.6.tar.gz: telemetrix-rpi-pico-0.6/README.md <==
# Telemetrix-RPi-Pico

This is an early version of a Telemetrix client for the Raspberry Pi Pico.

This is a work in progress.

A full User's Guide is under development.

A Python API for may be found [here.](https://htmlpreview.github.com/?https://github.com/MrYsLab/telemetrix-rpi-pico/blob/master/html/telemetrix_rpi_pico/index.html) 

The Pico server code may be viewed [here.](https://github.com/MrYsLab/Telemetrix4RpiPico)

The following functionality is implemented in this release:

* Autodetect and connection to a single PICO connected to the PC.
* Automatic board reset of the PICO using the watchdog timer when application exits.
    * Board will blink twice upon reset.
* Retrieval of the PICO unique ID.
* Analog Input
* Digital Input, Digital Input Pullup, Digital Input Pulldown
* PWM output
* Loopback (for client/server link debugging)
* I2C Support
* NeoPixel Support


## To install The Client Library:

**Linux/macOS:**

```bash
sudo pip3 install telemetrix-rpi-pico
```


**Windows:**


```bash
pip install telemetrix-rpi-pico 
```

### If you are upgrading from a previously installed version:

**Linux/macOS:**

```bash
sudo pip3 install telemetrix-rpi-pico --upgrade
```


**Windows:**


```bash
pip install telemetrix-rpi-pico --upgrade
```

## To Install The Pico Server Application
1. [Download](https://github.com/MrYsLab/Telemetrix4RpiPico/raw/master/cmake-build-release/Telemetrix4RpiPico.uf2) 
   and save the .uf2 file.
2. Place the Pico in file upload mode:
   
   A. Press and hold the BOOTSEL button while applying power. 
   
   B. Release the BOOTSEL button.
   
   C. In your file explorer, you should see a new folder appear called: RPI-RP2.
   
   D. Drag the .uf2 file into this folder to upload the code.

## Download And Run The Examples
   
1. [Download,](https://github.com/MrYsLab/telemetrix-rpi-pico/archive/master.zip) 
   save, and uncompress the teletmetrix-rpi-pico Github repository.
   
2. Open the _examples_ directory and run any of the examples. You may
modify them to suit your needs.
